DefaultRuntime

Struct DefaultRuntime 

pub struct DefaultRuntime;
The default runtime.

Automatically selects the runtime implementation based on the configured features and the platform on which it runs.